=========================================
Welcome to easyCore's documentation!
=========================================

**easyCore** is the foundation of the easyScience universe, providing the building blocks for libraries and applications which aim to make scientific data simulation and analysis easier.


Features of easyCore
=========================

Free and open-source
Anyone is free to use easyCore and the source code is openly shared on GitHub.

* *Cross-platform* - easyCore is written in Python and available for all platforms.

* *Various techniques* - easyCore has been used to build various libraries such as easyDiffraction and easyReflectometry.

* *Advanced built-in features* - easyCore provides features such as model minimization, automatic script generation, undo/redo, and more.


Projects using easyCore
============================

easyCore is currently being used in the following projects:

.. image:: https://raw.githubusercontent.com/easyScience/easyDiffractionWww/master/assets/img/card.png
   :target: https://easydiffraction.org

Scientific software for modelling and analysis of neutron diffraction data.

.. image:: https://raw.githubusercontent.com/easyScience/easyReflectometryWww/master/assets/img/card.png
   :target: https://easyreflectometry.org

Scientific software for modelling and analysis of neutron reflectometry data.

Documentation
------------------------------------------

.. toctree::
   :caption: Getting Started
   :maxdepth: 3

   getting-started/overview
   getting-started/installation


.. toctree::
   :caption: Base Classes
   :maxdepth: 3

   reference/base


.. toctree::
   :caption: Fitting
   :maxdepth: 3

   fitting/introduction
   fitting/constraints

.. toctree::
   :maxdepth: 2
   :caption: Example galleries

   base_examples/index
   fitting_examples/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`